@@ -156,7 +156,7 @@ class encryptAGit:
             return decrypted_file
 
         except Exception as e:
-            print('Invalid key! try again!')
+            print('⚠️  Invalid key! try again!')
             sys.exit(-1)
 
     def encryption_key(self, user_salt, password):
@@ -177,7 +177,7 @@ class encryptAGit:
             start = time.time()
             self.key = base64.urlsafe_b64encode(kdf.derive(bytes(password, 'iso-8859-1')))
             end = time.time()
-            print(f"[*] It took {end - start} seconds to make the key.")
+            print(f"💻 It took {end - start} seconds to make the key.")
             return True
 
         except Exception as e:
@@ -199,6 +199,13 @@ class encryptAGit:
         '''
         updates = False
 
+        # key check, check one file, if salt/key fail exit program.
+        for _afile, _values in self.decoded_json.items():
+            _decrypted_file = self.decrypt_file(_values['token'])
+            break
+
+        print(f"🔓 Salt/Password combo verified!")
+
         for afile, values in self.decoded_json.items():
             # check if file on disk
             # if not on disk, decrypt it
@@ -224,6 +231,21 @@ class encryptAGit:
 
         return updates
 
+    def git_setup(self):
+        '''
+        Make sure encrypted_git is added to repo
+        '''
+        open('encrypted_git.json', 'a')
+
+        try:
+            repo = Repo()
+            git = repo.git
+            git.add('encrypted_git.json')
+        except Exception as e:
+            print(f'[!!] No valid .git directory here? Exiting...')
+            os.remove('encrypted_git.json')
+            sys.exit(-1)
+
     def git_commit(self):
         '''
         This will attempt to commit and push encrypted_git.json... that's it
@@ -244,10 +266,11 @@ class encryptAGit:
         # warn the user on pushing errors.. but not every second.
         try:
             git = repo.git
+
             if 'branch is ahead' in git.status():
                 origin = repo.remote(name='origin')
                 origin.push()
-                print('[*] Push of encrypted_git.json complete!')
+                print('☁️ Push of encrypted_git.json complete!')
                 self.commit_counter = 0
 
         except Exception as e:
@@ -277,7 +300,7 @@ class encryptAGit:
 
             with open('encrypted_git.json', 'w') as f:
                 print('[*] Writing updated encrypted_git.json')
-                to_write = json.dumps(self.decoded_json)
+                to_write = json.dumps(self.decoded_json, indent=4, sort_keys=True)
                 f.write(to_write)
 
     def check_json(self):
@@ -314,11 +337,43 @@ class encryptAGit:
         self.key = b''
         self.salt = b''
 
+    def set_salt_password(self):
+        while True:
+            user_salt = getpass.getpass(prompt='🧂Enter your salt:',
+                                stream=None)
+            user_salt2 = getpass.getpass(prompt='🧂Enter your salt again for verification:',
+                                stream=None)
+            if user_salt == user_salt2:
+                break
+
+        while True:
+            password = getpass.getpass(prompt='🕵️ Enter your password:',
+                               stream=None)
+            password2 = getpass.getpass(prompt='🕵️ Enter your password again for verification:',
+                               stream=None)
+
+            if password == password2:
+                break
+
+        if not self.encryption_key(user_salt, password):
+            print('🤔 hmmm, exiting...')
+            sys.exit(-1)
+
+        print(f"🔐 Salt and password set!")
+        password = ''
+        password2 = ''
+        user_salt = ''
+        user_salt2 = ''
+
+
     def set_keying_material(self):
+        # add double entry for verification
+
         user_salt = getpass.getpass(prompt='🧂Enter your salt:',
-                            stream=None)
+                                stream=None)
+
         password = getpass.getpass(prompt='🕵️ Enter your password:',
-                           stream=None)
+                               stream=None)
 
         if not self.encryption_key(user_salt, password):
             print('🤔 hmmm, exiting...')
@@ -340,14 +395,16 @@ class encryptAGit:
         if not self.check_json():
             print("🤗 Welcome to encryptAGit! Let's encrypt your repo!")
             print("🤓 Use a passphrase for both salt and password. Remember what you enter!")
-            self.set_keying_material()
+            self.set_salt_password()
             self.update_json()
+            self.git_setup()
             # create encrypted_git.json
 
         else:
             print("😊 Welcome Back to encryptAGit! Let's decrypt your repo!")
             self.set_keying_material()
             files_to_update = self.unload_json()
+            self.git_setup()
             if files_to_update:
                 self.update_json()
 
@@ -366,7 +423,7 @@ class encryptAGit:
 """)
 
             if answer.lower() == 'y':
-                self.set_keying_material()
+                self.set_salt_password()
                 os.remove('encrypted_git.json')
 
             print('\n[*] Exiting')
